#!/bin/bash

# USAGE: sh run_workflow_call_on_file.sh <fastq file> 
# This script accepts the location of a fastq file and performs the following steps on it:
    ## starting with alignment using bwa
    ## convert the .sai to SAM -> BAM -> sorted BAM 


# load the modules
module load bwa samtools

# The first command is to change to our working directory
cd ~/Desktop/data-shell/workflow

# make directories to store output
mkdir -p results/sai
mkdir -p results/sam
mkdir -p results/bam

# Get input file and locations  
fq=$1

# Grab base of filename for future naming
base=$(basename $fq .fastq)
echo "Starting analysis of" $base

# set up output filenames and locations
sai=results/sai/$base.aligned.sai
sam=results/sam/$base.aligned.sam
bam=results/bam/${base}.aligned.bam
sorted_bam=results/bam/$base.aligned.sorted

# location to genome reference FASTA file
genome=ref_genome/ecoli_rel606.fasta

### Alignmemt

# Align the reads to the reference genome
bwa aln $genome $fq > $sai

# Convert the output to the SAM format
bwa samse $genome $sai $fq > $sam

# Convert the SAM file to BAM format
samtools view -S -b $sam > $bam

# Sort the BAM file
samtools sort $bam -o $sorted_bam
